==> labstack-java-0.4.1-sources.jar: test/Main.java <==
package test;

import com.labstack.Client;
import com.labstack.Fields;
import com.labstack.Level;
import com.labstack.Log;

public class Main {
    public static void main(String[] args) throws Exception {
        Client client = new Client("VouXFKK2A1TkuMUVz3wV2zvmapIdRuFM");
//        Email email = client.Email();
//        EmailMessage message = new EmailMessage("jack@labstack.com", "LabStack", "Hello");
//        message.setBody("Hello");
//        message.addAttachment("/tmp/walle.png");
//        message = email.send(message);
//        Store store = client.Store();
//        Document document = store.insert("users", new Document()
//                .add("name", "Jack")
//                .add("location", "Disney"));
//        StoreSearchResponse response = store.search("users", new SearchParameters()
//                .setQueryString("location:Disney"));
//        System.out.println(response.getTotal());
//        System.out.println(response.getTotal());
//        StoreSearchResponse response = store.query("key='user'", 0, 5);
//        System.out.println(response.getTotal());
        Log log = client.Log();
        log.setAppId("armor1");
        log.setAppName("armor");
        log.setLevel(Level.DEBUG);
        log.setBatchSize(20);
        log.setDispatchInterval(5);
        log.debug(new Fields().add("message", "debug message"));
//        log.debug("debug message");
//        log.info("%s message", "info");
//        log.warn("warn message");
//        log.error("error message");
//        log.fatal("fatal message");
    }
}

==> labstack-java-0.5.0-sources.jar: test/Main.java <==
package test;

import com.labstack.Client;
import com.labstack.Fields;
import com.labstack.Level;
import com.labstack.Log;

public class Main {
    public static void main(String[] args) throws Exception {
        Client client = new Client("VouXFKK2A1TkuMUVz3wV2zvmapIdRuFM");
//        Email email = client.Email();
//        EmailMessage message = new EmailMessage("jack@labstack.com", "LabStack", "Hello");
//        message.setBody("Hello");
//        message.addAttachment("/tmp/walle.png");
//        message = email.send(message);
//        Store store = client.Store();
//        Document document = store.insert("users", new Document()
//                .add("name", "Jack")
//                .add("location", "Disney"));
//        StoreSearchResponse response = store.search("users", new SearchParameters()
//                .setQueryString("location:Disney"));
//        System.out.println(response.getTotal());
//        System.out.println(response.getTotal());
//        StoreSearchResponse response = store.query("key='user'", 0, 5);
//        System.out.println(response.getTotal());
        Log log = client.Log();
        log.setLevel(Level.DEBUG);
        log.setFields(new Fields().add("app_id", "id").add("app_name", "name"));
        log.setBatchSize(20);
        log.setDispatchInterval(5);
        log.debug(new Fields().add("message", "debug message"));
//        log.debug("debug message");
//        log.info("%s message", "info");
//        log.warn("warn message");
//        log.error("error message");
//        log.fatal("fatal message");
    }
}
